@@ -5,6 +5,7 @@ use cargo::Config;
 use cargo_c::build::*;
 use cargo_c::cli::run_cargo_fallback;
 use cargo_c::cli::subcommand_build;
+use cargo_c::config::*;
 
 use structopt::clap::*;
 
@@ -45,7 +46,7 @@ fn main() -> CliResult {
 
     let mut ws = subcommand_args.workspace(&config)?;
 
-    let _ = cbuild(&mut ws, &config, &subcommand_args, "dev")?;
+    let _ = cbuild(&mut ws, &config, subcommand_args, "dev")?;
 
     Ok(())
 }
