@@ -6,6 +6,7 @@ use crate::target::Target;
 #[derive(Debug, Default, Clone)]
 pub struct ExtraTargets {
     pub include: Vec<(PathBuf, PathBuf)>,
+    pub data: Vec<(PathBuf, PathBuf)>,
 }
 
 impl ExtraTargets {
@@ -16,6 +17,7 @@ impl ExtraTargets {
         out_dir: Option<&Path>,
     ) -> anyhow::Result<()> {
         self.include = extra_targets(&capi_config.install.include, root_dir, out_dir)?;
+        self.data = extra_targets(&capi_config.install.data, root_dir, out_dir)?;
 
         Ok(())
     }
@@ -89,14 +91,14 @@ impl BuildTargets {
                 let shared_lib = targetdir.join(&format!("lib{}.dylib", lib_name));
                 (shared_lib, static_lib, None, None)
             }
-            ("windows", ref env) => {
-                let static_lib = if *env == "msvc" {
+            ("windows", env) => {
+                let static_lib = if env == "msvc" {
                     targetdir.join(&format!("{}.lib", lib_name))
                 } else {
                     targetdir.join(&format!("lib{}.a", lib_name))
                 };
                 let shared_lib = targetdir.join(&format!("{}.dll", lib_name));
-                let impl_lib = if *env == "msvc" {
+                let impl_lib = if env == "msvc" {
                     targetdir.join(&format!("{}.dll.lib", lib_name))
                 } else {
                     targetdir.join(&format!("{}.dll.a", lib_name))
