@@ -9,6 +9,7 @@ use structopt::clap::*;
 use structopt::StructOpt;
 
 // TODO: convert to a function using cargo opt()
+#[allow(dead_code)]
 #[derive(Clone, Debug, StructOpt)]
 struct Common {
     /// Path to directory where target should be copied to
@@ -30,6 +31,13 @@ struct Common {
     /// Path to directory for installing generated pkg-config .pc files
     #[structopt(long = "pkgconfigdir", parse(from_os_str))]
     pkgconfigdir: Option<PathBuf>,
+    /// Path to directory for installing read-only data (defaults to {prefix}/share)
+    #[structopt(long = "datarootdir", parse(from_os_str))]
+    datarootdir: Option<PathBuf>,
+    /// Path to directory for installing read-only application-specific data
+    /// (defaults to {datarootdir})
+    #[structopt(long = "datadir", parse(from_os_str))]
+    datadir: Option<PathBuf>,
     #[structopt(long = "dlltool", parse(from_os_str))]
     /// Use the provided dlltool when building for the windows-gnu targets.
     dlltool: Option<PathBuf>,
