@@ -84,7 +84,9 @@ impl LibType {
         let env = &target.env;
 
         match (os.as_str(), env.as_str()) {
-            ("linux", _) | ("freebsd", _) | ("dragonfly", _) | ("netbsd", _) => LibType::So,
+            ("linux", _) | ("freebsd", _) | ("dragonfly", _) | ("netbsd", _) | ("android", _) => {
+                LibType::So
+            }
             ("macos", _) | ("ios", _) => LibType::Dylib,
             ("windows", _) => LibType::Windows,
             _ => unimplemented!("The target {}-{} is not supported yet", os, env),
@@ -116,7 +118,14 @@ impl UnixLibNames {
             }
             LibType::Dylib => {
                 let lib = format!("lib{}.dylib", lib_name);
-                let lib_with_major_ver = format!("lib{}.{}.dylib", lib_name, lib_version.major);
+                let lib_with_major_ver = if lib_version.major == 0 {
+                    format!(
+                        "lib{}.{}.{}.dylib",
+                        lib_name, lib_version.major, lib_version.minor
+                    )
+                } else {
+                    format!("lib{}.{}.dylib", lib_name, lib_version.major)
+                };
                 let lib_with_full_ver = format!(
                     "lib{}.{}.{}.{}.dylib",
                     lib_name, lib_version.major, lib_version.minor, lib_version.patch
